#
#  Copyright 2000, G. Wade Johnson
#  Released under the same license as Perl.
#
#  Parse an XML document into DataDoc format.

package XML::Data::DataDoc::Style;

require 5.005;
use XML::Data::DataDoc;
use XML::Parser;

use strict;
use vars qw($VERSION);

require Exporter;

my @ISA = qw(Exporter);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

my @EXPORT_OK = ( );

my @EXPORT = qw( );
$VERSION = '0.5';


# Preloaded methods go here.
sub Init
 {
  my $expat = shift;
  $expat->{Partial} = [];
  $expat->{Tree}    = new XML::Data::DataDoc();
 }



sub XMLDecl
 {
  my $expat = shift;
  my $xml = $expat->{Tree};

  $xml->Version( shift );
  $xml->Encoding( shift );
  $xml->Standalone( shift );
 }


sub Start
 {
  my $expat = shift;
  my $elem = $expat->{Tree}->MakeElement( shift );

  $elem->Attrib( @_ );
#  while(@_)
#   {
#    my $n = shift;
#    $elem->{$n} = shift;
#   }

  push @{$expat->{Partial}}, $elem;
 }




sub End 
 {
  my $expat = shift;
  my $tag = shift;

  my $elem = pop @{$expat->{Partial}};
  die "Improper element nesting.\n" if $tag ne $elem->Type();
  if(@{$expat->{Partial}})
   {
    $expat->{Partial}->[-1]->AddContent( $elem );
   }
  else
   {
    $expat->{Tree}->AddContent( $elem );
   }
 }


sub Char
 {
  my $expat = shift;
  my $text  = $expat->{Tree}->MakeText( shift );

  if(@{$expat->{Partial}})
   {
    $expat->{Partial}->[-1]->AddContent( $text );
   }
  else
   {
    $expat->{Tree}->AddContent( $text );
   }
 }


sub Comment
 {
  my $expat = shift;
  my $cmt   = $expat->{Tree}->MakeComment( shift );

  if(@{$expat->{Partial}})
   {
    $expat->{Partial}->[-1]->AddContent( $cmt );
   }
  else
   {
    $expat->{Tree}->AddContent( $cmt );
   }
 }




sub Proc
 {
  my $expat = shift;
  my $proc  = $expat->{Tree}->MakePI( shift, shift );

  if(@{$expat->{Partial}})
   {
    $expat->{Partial}->[-1]->AddContent( $proc );
   }
  else
   {
    $expat->{Tree}->AddContent( $proc );
   }
 }  



sub Final
 {
  my $expat = shift;
  delete $expat->{Partial};
  $expat->{Tree};
 }



sub CdataStart
 {
  my $expat = shift;

  push @{$expat->{Partial}}, $expat->{Tree}->MakeCdata();
 }


sub CdataEnd
 {
  my $expat = shift;
  my $cdata = pop @{$expat->{Partial}};

  die "Improper CDATA closure.\n" if '#cdata' ne $cdata->Type();

  if(@{$expat->{Partial}})
   {
    $expat->{Partial}->[-1]->AddContent( $cdata );
   }
  else
   {
    $expat->{Tree}->AddContent( $cdata );
   }
 }

1;
__END__

=head1 NAME

XML::Data::DataDoc::Style - Perl extension for use with XML::Parser. It converts
an XML document into a DataDoc object.

=head1 SYNOPSIS

  use XML::Parser;
  use XML::Data::DataDoc;
  use XML::Data::DataDoc::Style;
  
  my $p = new XML::Parser( Style=>'XML::Data::DataDoc::Style' );

  my $doc = $p->parsefile( $file );

=head1 DESCRIPTION

XML::Data::DataDoc::Style is an XML::Parser Style package. It's sole purpose is to
convert an XML document read by XML::Parser into an XML::Data::DataDoc object.

=head2 EXPORT

None by default.

=head1 AUTHOR

G. Wade Johnson, gwadej@anomaly.org

=head1 SEE ALSO

perl(1).

XML::Data::DataDoc.

=cut
